@@ -1,7 +1,6 @@
 from uuid import UUID
 from typing import Dict, Optional, List
 
-
 """
 PEM and Artifact
 
@@ -59,8 +58,7 @@ class PEM:
         self.ProducesArtifacts: List[Artifact] = []
         self.TimestampReceived = ''
         self.Properties: dict = {}
-        self.Version = '1.0.0'
-        self.User = ''
+        self.Version = '1.0.1'
         self.Tag = ''
         self.TagNamespace = ''
 
@@ -76,3 +74,8 @@ class PEM:
 
     def __repr__(self):
         return self.__str__()
+
+    def __eq__(self, other):
+        return self.ID == other.ID and \
+            self.Type == other.Type and \
+            self.Properties == other.Properties
